@@ -30,6 +30,7 @@
 
 #include <QtGui/QKeyEvent>
 #include <QtGui/QAction>
+#include <QSortFilterProxyModel>
 
 #include <KColorDialog>
 #include <KNotification>
@@ -125,7 +126,12 @@ ChatWidget::ChatWidget(const Tp::TextChannelPtr & channel, const Tp::AccountPtr
         d->ui.sendMessageBox->setContactModel(d->contactModel);
     }
 
-    d->ui.contactsView->setModel(d->contactModel);
+    QSortFilterProxyModel *sortModel = new QSortFilterProxyModel(this);
+    sortModel->setSourceModel(d->contactModel);
+    sortModel->setSortRole(Qt::DisplayRole);
+    sortModel->setDynamicSortFilter(true);
+
+    d->ui.contactsView->setModel(sortModel);
 
     d->yourName = channel->groupSelfContact()->alias();
 
@@ -271,11 +277,6 @@ void ChatWidget::keyPressEvent(QKeyEvent *e)
         return;
     }
 
-    if (e->key() == Qt::Key_Escape && d->ui.searchBar->isVisible()) {
-        d->ui.searchBar->toggleView(false);
-        return;
-    }
-
     if (e->key() == Qt::Key_PageUp ||
         e->key() == Qt::Key_PageDown) {
         d->ui.chatArea->event(e);
